#! /usr/bin/env bash
PICARD='Tools/picard-tools-2.5.0/picard.jar'
GATK='Tools/GenomeAnalysisTK.jar -drf DuplicateRead'
infolder=gvcf
outfolder=gvcf
errfolder=logs

# define local variable
bundle=Reference
reference=${bundle}/ucsc.hg19.fasta 
dbsnp=${bundle}/dbsnp_138.hg19.vcf.gz
G1000=${bundle}/1000G_phase1.snps.high_confidence.hg19.sites.vcf
G1000v3=${bundle}/1000G_phase3_v4_20130502.hg19.lifted.sites.vcf


#uncomment later

java -jar $GATK \
	-T GenotypeGVCFs \
	--sample_rename_mapping_file sample_order.txt \
	-R ${reference} \
	--dbsnp ${dbsnp} \
	--variant ${infolder}/BRCA-BC1_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC2_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC3_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC4_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC5_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC6_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC7_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC8_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC9_S1.bamraw_variants.annot.g.vcf \
	--variant ${infolder}/BRCA-BC10_S1.bamraw_variants.annot.g.vcf \
	-o ${outfolder}/cohort.g.vcf \
	2>${errfolder}/CombineGVCFs_gvcf.err



java -jar $GATK \
	-T SelectVariants \
	-R ${reference} \
	-V ${infolder}/cohort.g.vcf \
	-selectType SNP \
	-o ${outfolder}/raw_snps.vcf \
	2>${errfolder}/SelectVariants.SNPs.err 

 java -jar $GATK \
	 -T VariantFiltration \
	 -R ${reference} \
	 -V ${infolder}/raw_snps.vcf \
	 --filterExpression "QD < 2.0" \
	 --filterName "lowQD" \
	 --filterExpression "FS > 60.0" \
	 --filterName "filtFS" \
	 --filterExpression "MQ < 40.0" \
	 --filterName "lowMQ"\
	 --filterExpression "MQRankSum < -12.5" \
	 --filterName "filtMQRankSum"\
	 --filterExpression "ReadPosRankSum < -8.0" \
	 --filterName "filtReadPosRankSum"\
	 --filterExpression "SB < -0.10" \
	 --filterName "SB"\
	 --filterExpression "DP < 10" \
	 --filterName "lowDP"\
	 --filterExpression "GQ < 30" \
	 --filterName "LowGQ"\
	 --filterExpression "SOR > 3.0"\
	 --filterName "filtSOR" \
	 -o ${outfolder}/filtered_snps.1.vcf \
	 2>${errfolder}/VariantFiltration.g.1.err 

	 
java -jar $GATK \
	-T SelectVariants \
	-R ${reference} \
	-V  ${infolder}/cohort.g.vcf \
	-selectType INDEL \
	-o ${outfolder}/raw_indels.vcf \
	2>${errfolder}/SelectVariants_indels.g.err

java -jar $GATK \
	-T VariantFiltration \
	-R ${reference} \
	-V ${infolder}/raw_indels.vcf \
	--filterExpression "QD < 2.0" \
	--filterName "LowQD" \
	--filterExpression "FS > 200.0" \
	--filterName "filtFS" \
	--filterExpression "ReadPosRankSum < -20.0" \
	--filterName "filtReadPosRankSum" \
	--filterExpression "InbreedingCoeff < -0.8"\
	--filterName "filtImbred"\
	--filterExpression "SOR > 10.0" \
	--filterName "filtSOR"\
	-o ${outfolder}/filtered_indels.vcf \
	2>${errfolder}/VariantFiltration_indels.g.err

java -jar $GATK \
	-R ${reference} \
	-T CalculateGenotypePosteriors \
	--supporting ${G1000v3} \
	-ped brca.ped\
	-V ${outfolder}/filtered_snps.1.vcf \
	-o ${outfolder}/filtered_snps.1.postCGP.vcf

java -jar $GATK \
	-T VariantFiltration \
	-R ${reference} \
	-V ${outfolder}/filtered_snps.1.postCGP.vcf \
	-G_filter "GQ < 20.0" -G_filterName lowGQ \
	-o ${outfolder}/filtered_snps.1.postCGP_filtered.vcf

java -jar $GATK \
	-T VariantAnnotator \
	-R ${reference} \
	-A PossibleDeNovo \
	-V gvcf/filtered_snps.1.postCGP_filtered.vcf \
	-o gvcf/BRCA_final_SNPs.vcf 


